pub struct CommentedToken<'a> {
pub token: Token<'a>,
pub offset: usize,
pub leading_comments: Option<Vec<&'a str>>,
pub inline_comment: Option<&'a str>,
}Expand description
Representation of a token.
This represents a single token in an R program along with the line on which it occurs and the column offset. Additionally, it stores the comments that are associated with the token.
Fields
token: Token<'a>The actual token stored in this struct.
offset: usizeThe column offset of the start of this token.
leading_comments: Option<Vec<&'a str>>Preceding comments.
inline_comment: Option<&'a str>Trailing inline comment.
Implementations